pub struct PlanRequest {
pub world: World,
pub start: Point2f,
pub goal: Point2f,
}Expand description
One planning problem. The map travels with the job, so the source owns it and may change it between jobs.
Fields
world: Worldstart: Point2fgoal: Point2fTrait Implementations
Sourceimpl<'__de, __Context> BorrowDecode<'__de, __Context> for PlanRequest
impl<'__de, __Context> BorrowDecode<'__de, __Context> for PlanRequest
Sourcefn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>(
decoder: &mut __D,
) -> Result<Self, DecodeError>
fn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>( decoder: &mut __D, ) -> Result<Self, DecodeError>
Attempt to decode this type with the given BorrowDecode.
Sourceimpl Clone for PlanRequest
impl Clone for PlanRequest
Sourcefn clone(&self) -> PlanRequest
fn clone(&self) -> PlanRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PlanRequest
impl Debug for PlanRequest
Sourceimpl<__Context> Decode<__Context> for PlanRequest
impl<__Context> Decode<__Context> for PlanRequest
Sourceimpl Default for PlanRequest
impl Default for PlanRequest
Sourcefn default() -> PlanRequest
fn default() -> PlanRequest
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PlanRequest
impl<'de> Deserialize<'de> for PlanRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Encode for PlanRequest
impl Encode for PlanRequest
Sourceimpl Serialize for PlanRequest
impl Serialize for PlanRequest